Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2142)

Unified Diff: chrome/browser/media/webrtc/webrtc_browsertest_base.h

Issue 2545553003: WebRtcStatsPerfBrowserTest added, a perf test using the new getStats (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/media/webrtc/webrtc_browsertest_base.h
diff --git a/chrome/browser/media/webrtc/webrtc_browsertest_base.h b/chrome/browser/media/webrtc/webrtc_browsertest_base.h
index eb7c45c57b33a0444e2ff687a1d1aa00dcacb988..826e17d6f9248756526c2cffe56b67c48d3895a5 100644
--- a/chrome/browser/media/webrtc/webrtc_browsertest_base.h
+++ b/chrome/browser/media/webrtc/webrtc_browsertest_base.h
@@ -43,6 +43,7 @@ class WebRtcTestBase : public InProcessBrowserTest {
static const char kFailedWithPermissionDismissedError[];
static const char kUseDefaultCertKeygen[];
+ static const char kUseDefaultAudioCodec[];
static const char kUseDefaultVideoCodec[];
protected:
@@ -174,7 +175,9 @@ class WebRtcTestBase : public InProcessBrowserTest {
std::vector<std::string> GetWhitelistedStatsTypes(
content::WebContents* tab) const;
- // Change the default video codec in the offer SDP.
+ // Change the default audio/video codec in the offer SDP.
+ void SetDefaultAudioCodec(content::WebContents* tab,
+ const std::string& audio_codec) const;
void SetDefaultVideoCodec(content::WebContents* tab,
const std::string& video_codec) const;

Powered by Google App Engine
This is Rietveld 408576698